@@ -32,15 +32,3 @@ def _mutable(func):
         return output
 
     return mutable_method
-
-
-class cached_method:
-    def __init__(self, func):
-        self.name = func.__name__
-        self.func = func
-
-    def __get__(self, instance, owner):
-        output = self.func(instance)
-        cached_func = ft.wraps(self.func)(lambda *args, **kwargs: output)
-        object.__setattr__(instance, self.name, cached_func)
-        return cached_func
