@@ -33,11 +33,6 @@ def is_nondiff_field(field_item: Field) -> bool:
     return isinstance(field_item, Field) and field_item.metadata.get("nondiff", False)
 
 
-def is_static_field(field_item: Field) -> bool:
-    """check if field is static"""
-    return isinstance(field_item, Field) and field_item.metadata.get("static", False)
-
-
 def is_treeclass_frozen(tree):
     """assert if a treeclass is frozen"""
     if is_treeclass(tree):
@@ -131,20 +126,18 @@ class _fieldDict(dict):
 
 def _tree_structure(tree) -> tuple[dict[str, Any], dict[str, Any]]:
     """Return dynamic and static fields of the pytree instance"""
-    # this property scans the class fields and returns a tuple of two dicts (dynamic, static)
+    # this function classifies tree vars into trainable/untrainable dict items
+    # and returns a tuple of two dicts (dynamic, static)
     # that mark the tree leaves seen by JAX computations and the static(tree structure) that are
     # not seen by JAX computations. the scanning is done if the instance is not frozen.
     # otherwise the cached values are returned.
-    dynamic = _fieldDict()
 
-    # undeclared fields are the fields that are not defined in the dataclass fields
-    static = _fieldDict(__undeclared_fields__=tree.__undeclared_fields__)
+    static, dynamic = _fieldDict(tree.__dict__), _fieldDict()
 
     for field_item in _tree_fields(tree).values():
-        if field_item.metadata.get("static", False):
-            static[field_item.name] = getattr(tree, field_item.name)
-        else:
-            dynamic[field_item.name] = getattr(tree, field_item.name)
+        if not field_item.metadata.get("static", False):
+            dynamic[field_item.name] = static.pop(field_item.name)
+
     return (dynamic, static)
 
 
@@ -269,9 +262,7 @@ def _unappend_field(tree: PyTree, cond: Callable[[Field], bool]) -> PyTree:
             elif cond(field_item):
                 new_fields = dict(tree.__undeclared_fields__)
                 new_fields.pop(field_item.name)
-                object.__setattr__(
-                    tree, "__undeclared_fields__", MappingProxyType(new_fields)
-                )
+                object.__setattr__(tree, "__undeclared_fields__", MappingProxyType(new_fields))  # fmt: skip
         return tree
 
     return _recurse(tree_copy(tree))
