@@ -1,8 +1,11 @@
+import copy
+
 import jax.tree_util as jtu
 import pytest
 from jax import numpy as jnp
 
 import pytreeclass as pytc
+from pytreeclass._src.tree_util import tree_copy
 
 
 def test_hash():
@@ -74,3 +77,31 @@ def test_nonclass_input():
         @pytc.treeclass
         def f(x):
             return x
+
+
+def test_registering_state():
+    @pytc.treeclass
+    class L0:
+        def __init__(self):
+            self.a = 10
+            self.b = 20
+
+    t = L0()
+    tt = tree_copy(t)
+
+    assert tt.a == 10
+    assert tt.b == 20
+
+
+def test_copy():
+    @pytc.treeclass
+    class L0:
+        a: int = 1
+        b: int = 3
+        c: int = 5
+
+    t = L0()
+
+    assert copy.copy(t).a == 1
+    assert copy.copy(t).b == 3
+    assert copy.copy(t).c == 5
