@@ -76,18 +76,6 @@ def test_getter_by_param():
 
     A = Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), ("A"))
 
-    B = A.at[A == "a"].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(10, None, None, None, ("A")))
-
-    B = A.at[(A == "a") | (A == "b")].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(10, 20, None, None, ("A")))
-
-    B = A.at[A == ""].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(None, None, None, None, ("A")))
-
-    B = A.at[(A == "a") | (A == "b") | (A == "c")].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(10, 20, 30, None, ("A")))
-
     B = A.at[(A == "a") | (A == "b") | (A == "c") | (A == "d")].get(
         array_as_leaves=False
     )
@@ -134,30 +122,6 @@ def test_getter_by_metadata():
         d: jnp.ndarray = field(metadata={"name": "d"})
         name: str = pytc.nondiff_field()
 
-    A = Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), ("A"))
-
-    B = A.at[A == {"name": "a"}].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(10, None, None, None, ("A")))
-
-    B = A.at[(A == {"name": "a"}) | (A == {"name": "b"})].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(10, 20, None, None, ("A")))
-
-    B = A.at[A == {"": ""}].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(None, None, None, None, ("A")))
-
-    B = A.at[(A == {"name": "a"}) | (A == {"name": "b"}) | (A == {"name": "c"})].get(
-        array_as_leaves=False
-    )
-    assert is_treeclass_equal(B, Test(10, 20, 30, None, ("A")))
-
-    B = A.at[
-        (A == {"name": "a"})
-        | (A == {"name": "b"})
-        | (A == {"name": "c"})
-        | (A == {"name": "d"})
-    ].get(array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(10, 20, 30, jnp.array([1, 2, 3, 4, 5]), ("A")))
-
     @pytc.treeclass
     class L0:
         a: int = field(default=1, metadata={"name": "a"})
@@ -283,14 +247,6 @@ def test_setter_by_metadata():
     )
     assert is_treeclass_equal(B, Test(100, 100, 100, jnp.array([1, 2, 3, 4, 5]), ("A")))
 
-    B = A.at[
-        (A == {"name": "a"})
-        | (A == {"name": "b"})
-        | (A == {"name": "c"})
-        | (A == {"name": "d"})
-    ].set(100, array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(100, 100, 100, 100, ("A")))
-
     @pytc.treeclass
     class L0:
         a: int = field(default=1, metadata={"name": "a"})
@@ -523,14 +479,6 @@ def test_apply_and_its_derivatives():
     )
     assert is_treeclass_equal(B, Test(100, 100, 100, jnp.array([1, 2, 3, 4, 5]), ("A")))
 
-    B = A.at[
-        (A == {"name": "a"})
-        | (A == {"name": "b"})
-        | (A == {"name": "c"})
-        | (A == {"name": "d"})
-    ].apply(lambda _: 100, array_as_leaves=False)
-    assert is_treeclass_equal(B, Test(100, 100, 100, 100, ("A")))
-
     B = A.at[A != {"name": "a"}].apply(lambda _: 100)
     assert is_treeclass_equal(
         B, Test(10, 100, 100, jnp.array([100, 100, 100, 100, 100]), ("A"))
